summaryrefslogtreecommitdiffstats
path: root/juk/k3bexporter.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'juk/k3bexporter.cpp')
-rw-r--r--juk/k3bexporter.cpp16
1 files changed, 8 insertions, 8 deletions
diff --git a/juk/k3bexporter.cpp b/juk/k3bexporter.cpp
index 6aec012f..aa89b005 100644
--- a/juk/k3bexporter.cpp
+++ b/juk/k3bexporter.cpp
@@ -41,20 +41,20 @@ using ActionCollection::actions;
PlaylistAction *K3bExporter::m_action = 0;
// Special KAction subclass used to automatically call a slot when activated,
// depending on the visible playlist at the time. In other words, use *one*
// instance of this action for many playlists.
//
// This is used to handle some actions in the Playlist context menu.
-class PlaylistAction : public KAction
+class PlaylistAction : public TDEAction
{
public:
PlaylistAction(const char *name,
const TQString &userText,
const TQIconSet &pix,
const char *slot,
- const KShortcut &cut = 0) :
- KAction(userText, pix, cut, 0 /* receiver */, 0 /* slot */, actions(), name),
+ const TDEShortcut &cut = 0) :
+ TDEAction(userText, pix, cut, 0 /* receiver */, 0 /* slot */, actions(), name),
m_slot(slot)
{
}
@@ -101,7 +101,7 @@ K3bExporter::K3bExporter(Playlist *parent) : PlaylistExporter(parent), m_parent(
{
}
-KAction *K3bExporter::action()
+TDEAction *K3bExporter::action()
{
if(!m_action && !TDEStandardDirs::findExe("k3b").isNull()) {
m_action = new PlaylistAction(
@@ -116,7 +116,7 @@ KAction *K3bExporter::action()
// Tell the action to let us know when it is activated when
// m_parent is the visible playlist. This allows us to reuse the
// action to avoid duplicate entries in KActionCollection.
if(m_action)
m_action->addCallMapping(m_parent, this);
@@ -268,10 +268,10 @@ K3bPlaylistExporter::K3bPlaylistExporter(PlaylistBox *parent) : K3bExporter(0),
{
}
-KAction *K3bPlaylistExporter::action()
+TDEAction *K3bPlaylistExporter::action()
{
if(!TDEStandardDirs::findExe("k3b").isNull()) {
- return new KAction(
+ return new TDEAction(
i18n("Add Playlist to Audio or Data CD"),
SmallIconSet("k3b"),
0,
@@ -41,20 +41,20 @@ using ActionCollection::actions;
PlaylistAction *K3bExporter::m_action = 0;
-// Special KAction subclass used to automatically call a slot when activated,
+// Special TDEAction subclass used to automatically call a slot when activated,
// depending on the visible playlist at the time. In other words, use *one*
// instance of this action for many playlists.
@@ -116,7 +116,7 @@ KAction *K3bExporter::action()
// Tell the action to let us know when it is activated when
// m_parent is the visible playlist. This allows us to reuse the
- // action to avoid duplicate entries in KActionCollection.
+ // action to avoid duplicate entries in TDEActionCollection.
if(m_action)
m_action->addCallMapping(m_parent, this);